#
# spec file for package python-iniparse
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2017 Neal Gompa <ngompa13@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-iniparse
Version:        0.4
Release:        lp151.4.2
Summary:        Python Module for Accessing and Modifying Configuration Data in INI files
License:        MIT
Group:          Development/Libraries/Python
Url:            http://code.google.com/p/iniparse/
Source:         http://iniparse.googlecode.com/files/iniparse-%{version}.tar.gz
# PATCH-FIX-UPSTREAM: speilicke@suse.com -- Backport of https://code.google.com/p/iniparse/issues/detail?id=31
Patch0:         iniparse-insert-after-commented-option.patch
# PATCH-FIX-UPSTREAM: timlau@fedoraproject.org -- Backport of https://code.google.com/p/iniparse/issues/detail?id=28
Patch1:         iniparse-fix-issue-28.patch
# PATCH-FIX-OPENSUSE: timlau@fedoraproject.org -- Variant of http://code.google.com/p/iniparse/issues/detail?id=22 that uses python-six to support py2+py3, from Fedora
Patch2:         python-iniparse-python3-compat.patch
# PATCH-FIX-OPENSUSE: ngompa13@gmail.com -- Fix setup.py to have correct information, from Fedora
Patch3:         python-iniparse-setup-fixes.patch

BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  python-rpm-macros
# tests require testsuite modules
BuildRequires:  python3-testsuite
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

Requires:       python-six

%python_subpackages

%description
iniparse is an INI parser for Python which is API compatible with the
standard library's ConfigParser, preserves structure of INI files
(order of sections & options, indentation, comments, and blank lines
are preserved when data is updated), and is more convenient to use.

%prep
%setup -q -n iniparse-%{version}
%patch0 -p0
%patch1 -p1
%patch2 -p0
%patch3 -p0

chmod 644 html/index.html
sed -i "/.*test_multiprocessing.*/d" tests/__init__.py # NOTE(saschpe): Doesn't work and I'm lazy

%build
%python_build

%install
%python_install
rm -rf %{buildroot}%{_datadir}/doc/iniparse-%{version} # Remove unwanted stuff

%check
%python_exec runtests.py

%files %{python_files}
%defattr(-,root,root,-)
%doc Changelog LICENSE LICENSE-PSF README html/*
%{python_sitelib}/*

%changelog
* Tue Nov 14 2017 jmatejek@suse.com
- require %%{python_module devel} instead of listing the devels one by one
* Thu Sep 14 2017 ngompa13@gmail.com
- Add missing python-six runtime dependency
* Tue Jun  6 2017 ngompa13@gmail.com
- Add patches from Fedora to enable Python 3 support
  * iniparse-fix-issue-28.patch
  * python-iniparse-python3-compat.patch
  * python-iniparse-setup-fixes.patch
- Convert to singlespec to offer Python 3 variant
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon May 27 2013 speilicke@suse.com
- Add iniparse-insert-after-commented-option.patch: See
  https://code.google.com/p/iniparse/issues/detail?id=31 for details
- Run testsuite
* Thu Feb 23 2012 berendt@b1-systems.de
- added missing build requirement python-devel for SLE
* Tue Jan 31 2012 saschpe@suse.de
- Spec file cleanup:
  * Simplified macro usage
  * Removed outdated %%clean section
  * Buildrequire python-distribute instead of setuptools
* Thu Sep 16 2010 coolo@novell.com
- update to 0.4
  * Fixed pickling and multiprocessing bugs
  * Enabled auto-addition of config attributes via square bracket
    syntax
  * Utility function to tidy INI files
  * Ability to change comment syntax for parsing Mercurial config
    files
  * Added ConfigParser exceptions and constants to the top-level
    iniparse module
* Wed Aug  5 2009 matejcik@suse.cz
- update to 0.3.1
  * minor bugfixes
  * better multi-line handling
* Wed Jan  7 2009 cthiel@suse.de
- initial package (version 0.2.4)
